@@ -23,7 +23,7 @@ from dash.dependencies import Input, Output
 from jupyter_dash import JupyterDash
 from trace_updater import TraceUpdater
 
-from .downsamplers import AbstractSeriesDownsampler, EveryNthPoint
+from .downsamplers import AbstractSeriesDownsampler, LTTB
 
 
 class FigureResampler(go.Figure):
@@ -33,7 +33,7 @@ class FigureResampler(go.Figure):
         self,
         figure: go.Figure = go.Figure(),
         default_n_shown_samples: int = 1000,
-        default_downsampler: AbstractSeriesDownsampler = EveryNthPoint(),
+        default_downsampler: AbstractSeriesDownsampler = LTTB(),
         resampled_trace_prefix_suffix: Tuple[str, str] = (
             '<b style="color:sandybrown">[R]</b> ',
             "",
@@ -52,7 +52,7 @@ class FigureResampler(go.Figure):
             * **Note**: this can be overridden within the `add_trace()` method.
         default_downsampler: AbstractSeriesDownsampler
             An instance which implements the AbstractSeriesDownsampler interface,
-            by default `EveryNthPoint`.
+            by default `LTTB`.
             This will be used as default downsampler.\n
             * **Note**: this can be overridden within the `add_trace()` method.
         resampled_trace_prefix_suffix: str, optional
@@ -343,8 +343,9 @@ class FigureResampler(go.Figure):
           To circumvent this, the `limit_to_view` argument can be set, which forces
           these low-frequency series to be also stored in the back-end.
         * `hf_x`, `hf_y`, and 'hf_hovertext` are useful when you deal with large amounts
-          of data (as it can increase the speed of this add_trace() method with ~30%)
-          Note: These arguments have priority over the trace's data and (hover)text
+           of data (as it can increase the speed of this add_trace() method with ~30%).
+           <br>
+          **Note**: These arguments have priority over the trace's data and (hover)text
           attributes.
 
         Parameters
@@ -543,9 +544,7 @@ class FigureResampler(go.Figure):
             [
                 dash.dcc.Graph(id="resample-figure", figure=go.Figure(self)),
                 TraceUpdater(
-                    id="trace-updater", 
-                    gdID="resample-figure",
-                    sequentialUpdate=False
+                    id="trace-updater", gdID="resample-figure", sequentialUpdate=False
                 ),
             ]
         )
@@ -566,9 +565,7 @@ class FigureResampler(go.Figure):
             Input("resample-figure", "relayoutData"),
             prevent_initial_call=True,
         )
-        def update_graph(
-            changed_layout: dict,
-        ) -> List[dict]:
+        def update_graph(changed_layout: dict) -> List[dict]:
             current_graph = self.to_dict()
             updated_trace_indices, cl_k = [], []
             if changed_layout:
@@ -624,9 +621,7 @@ class FigureResampler(go.Figure):
             for range_change_axis in xy_matches:
                 axis = range_change_axis.split(".")[0]
                 extra_layout_updates[f"{axis}.autorange"] = False
-
-            changed_layout.update(extra_layout_updates)
-            layout_traces_list.append(changed_layout)
+            layout_traces_list.append(extra_layout_updates)
 
             # 2. Create the additional trace data for the frond-end
             # Note that only updated trace-data is sent to the client
